Examples using combine class methods — Version 0.11.0.dev0

# Examples using combine class methods

Combine methods mixed over- and under-sampling methods. Generally SMOTE is used for over-sampling while some cleaning methods (i.e., ENN and Tomek links) are used to under-sample.

Compare sampler combining over- and under-sampling

Compare sampler combining over- and under-sampling

previous

Fitting model on imbalanced datasets and how to fight bias

next

Compare sampler combining over- and under-sampling